==> dokuwiki-2012.10.13.tgz: dokuwiki/lib/plugins/plugin/lang/ko/lang.php <==
<?php
/**
 * korean language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author jk Lee
 * @author dongnak@gmail.com
 * @author Song Younghwan <purluno@gmail.com>
 * @author SONG Younghwan <purluno@gmail.com>
 * @author Seung-Chul Yoo  <dryoo@live.com>
 * @author erial2@gmail.com
 * @author Myeongjin <aranet100@gmail.com>
 */
$lang['menu']                  = '플러그인 관리자';
$lang['download']              = '새 플러그인 다운로드 및 설치';
$lang['manage']                = '이미 설치한 플러그인';
$lang['btn_info']              = '정보';
$lang['btn_update']            = '업데이트';
$lang['btn_delete']            = '삭제';
$lang['btn_settings']          = '설정';
$lang['btn_download']          = '다운로드';
$lang['btn_enable']            = '저장';
$lang['url']                   = 'URL';
$lang['installed']             = '설치됨:';
$lang['lastupdate']            = '가장 나중에 업데이트됨:';
$lang['source']                = '내용:';
$lang['unknown']               = '알 수 없음';
$lang['updating']              = '업데이트 중 ...';
$lang['updated']               = '%s 플러그인을 성공적으로 업데이트했습니다';
$lang['updates']               = '다음 플러그인을 성공적으로 업데이트했습니다';
$lang['update_none']           = '업데이트를 찾을 수 없습니다.';
$lang['deleting']              = '삭제 중 ...';
$lang['deleted']               = '%s 플러그인이 삭제되었습니다.';
$lang['downloading']           = '다운로드 중 ...';
$lang['downloaded']            = '%s 플러그인이 성공적으로 설치되었습니다.';
$lang['downloads']             = '다음 플러그인이 성공적으로 설치되었습니다:';
$lang['download_none']         = '플러그인이 없거나 다운로드 또는 설치 중에 알 수 없는 문제가 발생했습니다.';
$lang['plugin']                = '플러그인:';
$lang['components']            = '구성 요소';
$lang['noinfo']                = '이 플러그인은 어떤 정보도 없습니다. 잘못된 플러그인일 수 있습니다.';
$lang['name']                  = '이름:';
$lang['date']                  = '날짜:';
$lang['type']                  = '종류:';
$lang['desc']                  = '설명:';
$lang['author']                = '만든이:';
$lang['www']                   = '웹:';
$lang['error']                 = '알 수 없는 문제가 발생했습니다.';
$lang['error_download']        = '플러그인 파일을 다운로드 할 수 없습니다: %s';
$lang['error_badurl']          = '잘못된 URL 같습니다 - URL에서 파일 이름을 알 수 없습니다.';
$lang['error_dircreate']       = '다운로드를 받기 위한 임시 디렉토리를 만들 수 없습니다.';
$lang['error_decompress']      = '플러그인 관리자가 다운로드 받은 파일을 압축을 풀 수 없습니다. 잘못 다운로드 받았을 수도 있으니 다시 한번 시도해보기 바랍니다. 또는 압축 포맷을 알 수 없는 경우에는 다운로드한 후 수동으로 직접 설치하기 바랍니다.';
$lang['error_copy']            = '플러그인을 설치하는 동안 파일 복사하는 데 오류가 발생했습니다. <em>%s</em>: 디스크가 꽉 찼거나 파일 접근 권한이 잘못된 경우입니다. 플러그인 설치가 부분적으로만 이루어졌을 것입니다. 설치가 불완전합니다.';
$lang['error_delete']          = '<em>%s</em> 플러그인을 삭제하는 동안 오류가 발생했습니다. 대부분의 경우 불완전한 파일이거나 디렉토리 접근 권한이 잘못된 경우입니다.';
$lang['enabled']               = '%s 플러그인을 활성화했습니다.';
$lang['notenabled']            = '%s 플러그인을 활성화할 수 없습니다. 파일 권한을 확인하십시오.';
$lang['disabled']              = '%s 플러그인을 비활성화했습니다.';
$lang['notdisabled']           = '%s 플러그인을 비활성화할 수 없습니다. 파일 권한을 확인하십시오.';
$lang['packageinstalled']      = '플러그인 패키지(플러그인 %d개: %s)가 성공적으로 설치되었습니다.';

==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/plugin/lang/ko/lang.php <==
<?php
/**
 * Korean language file
 *
 * @license GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author jk Lee
 * @author dongnak@gmail.com
 * @author Song Younghwan <purluno@gmail.com>
 * @author Seung-Chul Yoo <dryoo@live.com>
 * @author erial2@gmail.com
 * @author Myeongjin <aranet100@gmail.com>
 */
$lang['menu']                  = '플러그인 관리자';
$lang['download']              = '새 플러그인 다운로드 및 설치';
$lang['manage']                = '이미 설치한 플러그인';
$lang['btn_info']              = '정보';
$lang['btn_update']            = '업데이트';
$lang['btn_delete']            = '삭제';
$lang['btn_settings']          = '설정';
$lang['btn_download']          = '다운로드';
$lang['btn_enable']            = '저장';
$lang['url']                   = 'URL';
$lang['installed']             = '설치됨:';
$lang['lastupdate']            = '가장 나중에 업데이트됨:';
$lang['source']                = '내용:';
$lang['unknown']               = '알 수 없음';
$lang['updating']              = '업데이트 중 ...';
$lang['updated']               = '%s 플러그인을 성공적으로 업데이트했습니다';
$lang['updates']               = '다음 플러그인을 성공적으로 업데이트했습니다';
$lang['update_none']           = '업데이트를 찾을 수 없습니다.';
$lang['deleting']              = '삭제 중 ...';
$lang['deleted']               = '%s 플러그인이 삭제되었습니다.';
$lang['downloading']           = '다운로드 중 ...';
$lang['downloaded']            = '%s 플러그인이 성공적으로 설치되었습니다';
$lang['downloads']             = '다음 플러그인이 성공적으로 설치되었습니다:';
$lang['download_none']         = '플러그인이 없거나 다운로드 또는 설치 중에 알 수 없는 문제가 발생했습니다.';
$lang['plugin']                = '플러그인:';
$lang['components']            = '구성 요소';
$lang['noinfo']                = '이 플러그인은 어떤 정보도 없습니다. 잘못된 플러그인일 수 있습니다.';
$lang['name']                  = '이름:';
$lang['date']                  = '날짜:';
$lang['type']                  = '종류:';
$lang['desc']                  = '설명:';
$lang['author']                = '만든이:';
$lang['www']                   = '웹:';
$lang['error']                 = '알 수 없는 문제가 발생했습니다.';
$lang['error_download']        = '플러그인 파일을 다운로드 할 수 없습니다: %s';
$lang['error_badurl']          = '잘못된 URL 같습니다 - URL에서 파일 이름을 알 수 없습니다';
$lang['error_dircreate']       = '다운로드를 받기 위한 임시 디렉토리를 만들 수 없습니다';
$lang['error_decompress']      = '플러그인 관리자가 다운로드 받은 파일을 압축을 풀 수 없습니다. 잘못 다운로드 받았을 수도 있으니 다시 한번 시도하거나 압축 포맷을 알 수 없는 경우에는 다운로드한 후 수동으로 직접 설치하세요.';
$lang['error_copy']            = '플러그인을 설치하는 동안 파일 복사하는 데 오류가 발생했습니다. <em>%s</em>: 디스크가 꽉 찼거나 파일 접근 권한이 잘못된 경우입니다. 플러그인 설치가 부분적으로만 이루어졌을 것입니다. 설치가 불완전합니다.';
$lang['error_delete']          = '<em>%s</em> 플러그인을 삭제하는 동안 오류가 발생했습니다. 대부분의 경우 불완전한 파일이거나 디렉토리 접근 권한이 잘못된 경우입니다';
$lang['enabled']               = '%s 플러그인을 활성화했습니다.';
$lang['notenabled']            = '%s 플러그인을 활성화할 수 없습니다. 파일 권한을 확인하세요.';
$lang['disabled']              = '%s 플러그인을 비활성화했습니다.';
$lang['notdisabled']           = '%s 플러그인을 비활성화할 수 없습니다. 파일 권한을 확인하하세요.';
$lang['packageinstalled']      = '플러그인 패키지(플러그인 %d개: %s)가 성공적으로 설치되었습니다.';
